Learn R Programming

mpe (version 1.0)

print.power.mpe.test: Print Methods for Hypothesis Tests, Sample size and Power Calculations

Description

Printing objects of class "mpe.tst" and "power.mpe.test" by simple print methods.

Usage

"print"(x, digits = getOption("digits"), prefix = "\t", ...) "print"(x, digits = getOption("digits"), ...)

Arguments

x
object of class "mpe.test" or "power.mpe.test".
digits
number of significant digits to be used.
prefix
string, passed to strwrap for displaying the method component of the mpe.test object.
...
further arguments to be passed to or from methods.

Value

the argument x, invisibly, as for all print methods.

Details

The print methods are based on the respective methods print.htest and print.power.htest of package stats.

A power.mpe.test object is just a named list of numbers and character strings, supplemented with method and note elements. The method is displayed as a title, the note as a footnote, and the remaining elements are given in an aligned ‘name = value’ format.

See Also

print.power.htest power.known.var, power.unknown.var, mpe.z.test, mpe.t.test.

Examples

Run this code
(pkv <- power.known.var(K = 2, delta = c(1,1), Sigma = diag(c(2,2)), power = 0.9,
                        sig.level = 0.025))
  print(pkv, digits =  4) # using less digits than default
  print(pkv, digits = 12) # using more  "       "

Run the code above in your browser using DataLab